pub struct ToolRegistry { /* private fields */ }Implementations
Sourceimpl ToolRegistry
impl ToolRegistry
pub fn register<T>(&mut self, tool: T)where
T: Tool + 'static,
Sourcepub fn get(&self, name: &str) -> Option<Arc<dyn Tool>>
pub fn get(&self, name: &str) -> Option<Arc<dyn Tool>>
Returns the registered tool implementation for the supplied name.
Sourcepub fn descriptors(&self) -> Vec<ToolDescriptor>
pub fn descriptors(&self) -> Vec<ToolDescriptor>
Returns cloned descriptors for every registered tool.
Sourcepub fn plan_exposure(&self, request: &ToolExposureRequest) -> ToolExposurePlan
pub fn plan_exposure(&self, request: &ToolExposureRequest) -> ToolExposurePlan
Computes which tools may be exposed for a planner request.